DownloadManager class

Constructors

DownloadManager()

Properties

downloadInPart bool
getter/setter pair
downloadSize int
getter/setter pair
endpart List<Downloader>
getter/setter pair
fileExists bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
limitSend int
getter/setter pair
mainStatus ManDownload
getter/setter pair
mergePart ↔ MergePartDownload
getter/setter pair
numDownloadComplete int
getter/setter pair
numPart int
getter/setter pair
nunRun int
getter/setter pair
rcv ReceivePort
getter/setter pair
reciverData StreamSubscription
getter/setter pair
request ↔ ManReques
getter/setter pair
runProcessDownloads List<Future<void>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendInterval Timer
getter/setter pair
sendPort SendPort
getter/setter pair
speed ↔ Velocity
getter/setter pair
startInit bool
getter/setter pair
startTime int
getter/setter pair
statusDownload StatusDownloadSendPort
getter/setter pair
sub Map<int, StreamSubscription>
getter/setter pair
tokenDownload int
getter/setter pair
tokenIsolate int
getter/setter pair
totalSize int
getter/setter pair

Methods

addSuscription(Stream<(downloadType, int)> stream, int id) → dynamic
createIsolate(RequestCreate requestIso) → dynamic
download({bool forceStart = false}) → dynamic
downloadPart() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendStatus() → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited